require_relative "./auth.rb"
require_relative "./api_response"

class LifePex::Systems::UserPexSystem < LifePex::Systems::AuthSystem
  include JSON::API
  include LifePex::Systems::ApiResponse

  extend DocMyRoutes::Annotatable # included by PexSystem
  register Sinatra::Namespace # included by PexSystem
  namespace '/api/user-pex/v1' do

    namespace '/pexs' do

      summary 'Get the amount of user_pex for a given day'
      produces 'application/json'
      status_codes [200]
      get "/:pex_id/amount/by-date/:date", auth: [], provides: 'json' do
        pex_id = params["pex_id"]
        date = params["date"]
        count = LifePex::UserPex.where(
          user_id: current_user_id,
          pex_id: pex_id,
          created_at: date,
        ).count
        api_response({ count: count, entity_type: 'user_pex' })
      end

      summary 'Create a new user_pex for a given day'
      produces 'application/json'
      status_codes [200]
      post "/:pex_id/validation", auth: [], provides: 'json' do
        pex_id = params["pex_id"]
        date = json_params["date"] || Date.today.to_s
        user_pex = LifePex::UserPex.new(
          user_id: current_user_id,
          pex_id: pex_id,
          created_at: date,
        ).save
        api_response_entity(
          "Successfuly added one user_pex",
          "user_pex",
          user_pex,
        )
      end

      summary 'Remove an existing user_pex for a given day'
      produces 'application/json'
      status_codes [200]
      delete "/:pex_id/validation", auth: [], provides: 'json' do
        pex_id = params["pex_id"]
        date = json_params["date"] || Date.today.to_s
        user_pex = LifePex::UserPex.find(
          user_id: current_user_id,
          pex_id: pex_id,
          created_at: date,
        )
        if user_pex
          user_pex.destroy
          api_response({
            message: "Successfuly destroyed 1 user_pex",
            entity_type: "user_pex",
            count: 1,
          })
        else
          api_error(400, "Nothing to destroy")
        end
      end

    end

  end
  include LifePex::Systems::ApiList
end
